/* ----------------------------------------------------------
                      fr_hwpins.c

     Anschluesse des Fuse Reseters

     Beinhaltet Makros zum Initialisieren der Anschluesse
     als Ein- oder Ausgang sowie Makros zum Setzen der
     Logikpegel an diesen Anschluessen sowie Makros zum
     Einlesen von Pegelwerten

     20.12.2019   R. Seelig
   ---------------------------------------------------------- */

#ifndef in_hwpins
  #define in_hwpins

  // PB1 fuer PWM als Ausgang
  #define pwmpin_init()    PB1_output_init()           // Arduino D9 => PWM Ausgang

  // pwr12 und pwr5 sind die Schalter, die die Spannung am MCLR (ICSP) des Flashershields schalten
  #define pwr12_init()     PC1_output_init()           // Arduino A1 => Pin zum Schalten 12V; 0 = an
  #define pwr5_init()      PC3_output_init()           // Arduino A3 => Pin zum Schalten 5V; 0 = an

  #define set_12v_on()     PC1_clr()
  #define set_12v_off()    PC1_set()

  #define set_5v_on()      PC3_clr()
  #define set_5v_off()     PC3_set()

  // ub schaltet die Vcc/Vdd am Target ein, Vdd (ICSP)
  #define ub_init()        PD3_output_init()           // Arduino D3 => Vcc Schalter fuer Target, 0 = an

  #define set_ub_on()      PD3_clr()
  #define set_ub_off()     PD3_set()

  // die an der HVSP beteiligten Anschluesse
  #define sdi_init()       PB3_output_init()           // Arduino 11 => serial data                   (mosi-isp)
  #define sii_init()       PB2_output_init()           // Arduino 10 => serial command                (rst-isp)
  #define scl_init()       PB5_output_init()           // Arduino 13 => serial clock                  (scl-isp)
  #define sdo_init()       PB4_input_init()            // Arduino 12 => SDO (data output from target) (miso-isp)

  #define sdi_set()        PB3_set()
  #define sdi_clr()        PB3_clr()
  #define sii_set()        PB2_set()
  #define sii_clr()        PB2_clr()
  #define scl_set()        PB5_set()
  #define scl_clr()        PB5_clr()

  #define is_sdo()         is_PB4()

  // LED-Anschluesse als Ausgang

  #define ledgn_init()     PC2_output_init()
  #define ledge_init()     PC5_output_init()
  #define ledrt_init()     PD5_output_init()

  #define ledgn_on()       PC2_set()
  #define ledgn_off()      PC2_clr()
  #define ledge_on()       PC5_set()
  #define ledge_off()      PC5_clr()
  #define ledrt_on()       PD5_set()
  #define ledrt_off()      PD5_clr()

  // Taster
  #define button_init()    PB0_input_init()
  #define is_button()      ( !(is_PB0()) )


#endif